@@ -16,20 +16,18 @@
  *
  * This file has been modified to not rely on tcl, tk or X11.
  * Based on tkArgv.c from tk2.3 : 
-static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/ParseArgv.c,v 6.2 2002/10/30 13:53:02 jason Exp $ SPRITE (Berkeley)";
+static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/ParseArgv.c,v 6.4 2004/04/15 21:18:56 bert Exp $ SPRITE (Berkeley)";
  *
  * Modifications by Peter Neelin (November 27, 1992)
  */
-
+#include "config.h"
+#include "minc_private.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 #include <ParseArgv.h>
 
-#define TRUE  1
-#define FALSE 0
-
 /*
  * Default table of argument descriptors.  These are normally available
  * in every application.
@@ -38,6 +36,8 @@ static char rcsid[] = "$Header: /software/source/minc/cvsroot/minc/libsrc/ParseA
 static ArgvInfo defaultTable[] = {
     {"-help",	ARGV_HELP,	(char *) NULL,	(char *) NULL,
 	"Print summary of command-line options and abort"},
+    {"-version", ARGV_VERSION,  (char *) NULL,  (char *) NULL,
+        "Print version number of program and exit"},
     {NULL,	ARGV_END,	(char *) NULL,	(char *) NULL,
 	(char *) NULL}
 };
@@ -47,6 +47,7 @@ static ArgvInfo defaultTable[] = {
  */
 
 static void	PrintUsage _ANSI_ARGS_((ArgvInfo *argTable, int flags));
+static void     PrintVersion(ArgvInfo *argTable);
 
 /*
  *----------------------------------------------------------------------
@@ -57,7 +58,8 @@ static void	PrintUsage _ANSI_ARGS_((ArgvInfo *argTable, int flags));
  *	command-line options.  See the manual page for more details.
  *
  * Results:
- *	The return value is a Boolean value with TRUE indicating an error.  
+ *	The return value is a Boolean value with non-zero indicating an 
+ *      error.  
  *	If an error occurs then an error message is printed on stderr.
  *	Under normal conditions, both *argcPtr and *argv are modified
  *	to return the arguments that couldn't be processed here (they
@@ -285,6 +287,9 @@ ParseArgv(argcPtr, argv, argTable, flags)
       case ARGV_HELP:
          PrintUsage (argTable, flags);
          return TRUE;
+      case ARGV_VERSION:
+         PrintVersion(argTable);
+         return FALSE;
       default:
          FPRINTF(stderr, "bad argument type %d in ArgvInfo",
                  infoPtr->type);
@@ -374,6 +379,9 @@ PrintUsage(argTable, flags)
    for (i = 0; ; i++) {
       for (infoPtr = i ? defaultTable : argTable;
            infoPtr->type != ARGV_END; infoPtr++) {
+         if (infoPtr->type == ARGV_VERINFO) {
+            continue;
+         }
          if ((infoPtr->type == ARGV_HELP) && (infoPtr->key == NULL)) {
             FPRINTF(stderr, "\n%s", infoPtr->help);
             continue;
@@ -441,3 +449,21 @@ PrintUsage(argTable, flags)
 
    FPRINTF(stderr, "\n");
 }
+
+static void PrintVersion(ArgvInfo *argTable)
+{
+    char *versionStr = VERSION;
+
+    for ( ; argTable->type != ARGV_END; argTable++) {
+        if (argTable->type == ARGV_VERINFO) {
+            /* Version information found? */
+            if (argTable->src != NULL) {
+                versionStr = argTable->src;
+                break;
+            }
+        }
+    }
+    printf("program: %s\n", versionStr);
+    printf("libminc: %s\n", miget_version());
+    exit(0);
+}
