@@ -19,6 +19,15 @@
 @CREATED    : July 24, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: minc.h,v $
+ * Revision 6.11.2.1  2004/08/11 21:03:06  bert
+ * Fix MI_MAX_IMGDIMS at 100 to avoid netCDF 3.5.1 problem
+ *
+ * Revision 6.11  2004/04/15 21:13:21  bert
+ * Add C++ linkage specifier
+ *
+ * Revision 6.10  2004/02/02 18:22:34  bert
+ * Added miget_version() and miappend_history()
+ *
  * Revision 6.9  2003/03/17 16:03:28  bert
  * Added declaration of micreate_tempfile()
  *
@@ -113,11 +122,15 @@
               make no representations about the suitability of this
               software for any purpose.  It is provided "as is" without
               express or implied warranty.
-@RCSID      : $Header: /software/source/minc/cvsroot/minc/libsrc/minc.h,v 6.9 2003/03/17 16:03:28 bert Exp $ MINC (MNI)
+@RCSID      : $Header: /software/source/minc/cvsroot/minc/libsrc/minc.h,v 6.11.2.1 2004/08/11 21:03:06 bert Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 #include <netcdf.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* For compatibility with NetCDF 2.x which uses NC_LONG rather than NC_INT.
    Since NC_INT is defined in an enum, and since there are no version macros,
    we use NC_FILL_INT as an indicator of whether NC_INT is defined. */
@@ -148,7 +161,17 @@
 /* Number of spatial dimensions */
 #define MI_NUM_SPACE_DIMS 3
 /* Maximum number of image dimensions for image conversion */
-#define MI_MAX_IMGDIMS MAX_VAR_DIMS
+
+/* Bert 10-Aug-2004 - MI_MAX_IMGDIMS used to be defined to be MAX_VAR_DIMS,
+ * a constant defined in netcdf.h. For many years MAX_VAR_DIMS was 100,
+ * but in netCDF 3.5.1 the value was changed to 512.
+ * Unfortunately, the definitions of MI_ICV_DIM_SIZE, MI_ICV_DIM_STEP,
+ * and MI_ICV_DIM_START assume that MI_MAX_IMGDIMS is less than or
+ * equal to 100.  To avoid changing the MINC API, we have to define
+ * MI_MAX_IMGDIMS to 100 here.  Otherwise the miicv_inqdbl() function
+ * will return bogus values for these ICV properties.
+ */
+#define MI_MAX_IMGDIMS 100
 
 /* NetCDF standard attributes */
 #define MIunits       "units"
@@ -482,6 +505,8 @@ public int miadd_child(int cdfid, int parent_varid, int child_varid);
 public int micreate_std_variable(int cdfid, char *name, nc_type datatype, 
                                  int ndims, int dim[]);
 public int micreate_group_variable(int cdfid, char *name);
+public const char *miget_version(void);
+public int miappend_history(int fd, const char *tm_stamp);
 
 /* From image_conversion.c */
 public int miicv_create(void);
@@ -508,5 +533,9 @@ public int miicv_attach(int icvid, int cdfid, int varid);
 #undef MINC_NEED_TO_UNDEF_PUBLIC
 #endif
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 /* End ifndef MINC_HEADER_FILE */
 #endif
