@@ -19,6 +19,9 @@ McGill University
 This is predominately a rehash of mincmath by Peter Neelin
 
  * $Log: minccalc.c,v $
+ * Revision 1.8.2.1  2004/06/11 21:36:53  bert
+ * Fix for nasty bug which causes lots of bogus zero values to be inserted when minccalc is used with a file with a vector_dimension
+ *
  * Revision 1.8  2001/05/24 15:08:40  neelin
  * Added support for comments so that minccalc scripts can be created.
  *
@@ -63,7 +66,7 @@ Mon May 21 01:01:01 EST 2000 - Original version "imgcalc" by David Leonard
 ---------------------------------------------------------------------------- */
 
 #ifndef lint
-static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/minccalc/minccalc.c,v 1.8 2001/05/24 15:08:40 neelin Exp $";
+static char rcsid[]="$Header: /software/source/minc/cvsroot/minc/progs/minccalc/minccalc.c,v 1.8.2.1 2004/06/11 21:36:53 bert Exp $";
 #endif
 
 #include <stdlib.h>
@@ -396,6 +399,7 @@ public void do_math(void *caller_data, long num_voxels,
    long ivox, ibuff, ivalue, nvox;
    scalar_t scalar, *output_scalars;
    int num_output, iout;
+   long total_values;  /* Total # of values to process in this call */
 
    /* Check arguments */
    if ((output_num_buffers < 1) || 
@@ -403,14 +407,17 @@ public void do_math(void *caller_data, long num_voxels,
       (void) fprintf(stderr, "Bad arguments to do_math!\n");
       exit(EXIT_FAILURE);
    }
-   
+
+   total_values = num_voxels * input_vector_length;
+
    /* Loop through the voxels */
-   for (ivox=0; ivox < num_voxels*input_vector_length; ivox+=eval_width) {
+   for (ivox=0; ivox < total_values; ivox+=eval_width) {
 
       /* Figure out how many voxels to work on at once */
       nvox = eval_width;
-      if (ivox + nvox > num_voxels) nvox = num_voxels - ivox;
-
+      if (ivox + nvox > total_values) 
+          nvox = total_values - ivox;
+      
       /* Copy the data into the A vector */
       for (ivalue=0; ivalue < nvox; ivalue++) {
          for (ibuff=0; ibuff < input_num_buffers; ibuff++){
